----------------------------------------------------------------------------------------------------
-- PickupAction
----------------------------------------------------------------------------------------------------
-- Purpose: Class for picking up action.
--
-- Copyright (c) Wopster, 2020
----------------------------------------------------------------------------------------------------

---@class PickupAction
PickupAction = {}
local PickupAction_mt = Class(PickupAction, CheckpointAction)

---Creates an PickupAction instance.
---@return PickupAction
function PickupAction:new(checkpoint)
    local self = CheckpointAction:new(checkpoint, PickupAction_mt)

    checkpoint.actionOnlyFulfillment = true
    self.vehicleToPickup = nil

    return self
end

function PickupAction:reset()
    PickupAction:superClass().reset(self)
    self.vehicleToPickup = nil
end

function PickupAction:loadFromXML(xmlFile, baseKey)
    self.distanceThreshold = Utils.getNoNil(getXMLFloat(xmlFile, baseKey .. "#vehicleDistance"), 2)
    return true
end

function PickupAction:validate(params)
    local object = unpack(params)

    if object == nil then
        local vehicleNode = self.vehicleToPickup.rootNode

        --Check if we are further away than the threshold distance (to verify that we moved).
        if calcDistanceFrom(self.checkpoint.triggerNode, vehicleNode) > self.distanceThreshold then
            --Check if we have an attacher vehicle.
            if self.vehicleToPickup.getAttacherVehicle ~= nil and self.vehicleToPickup:getAttacherVehicle() ~= nil then
                self.fulfilled = true
            end
        end
    end
end

function PickupAction:checkpointTriggerCallback(triggerId, otherId, onEnter, onLeave, onStay, otherShapeId)
    if onEnter and self.vehicleToPickup == nil then
        local object = g_currentMission:getNodeObject(otherId)

        if object ~= nil then
            self.vehicleToPickup = object
        end
    end
end
