----------------------------------------------------------------------------------------------------
-- Checkpoint
----------------------------------------------------------------------------------------------------
-- Purpose: Base Checkpoint class to handle checkpoints for the super cup.
--
-- Copyright (c) Wopster, 2020
----------------------------------------------------------------------------------------------------

---@class Checkpoint
Checkpoint = {}

local Checkpoint_mt = Class(Checkpoint)

---Creates a new Checkpoint instance.
---@return Checkpoint
function Checkpoint:new(nodeId, isServer, isClient, customMt)
    local self = setmetatable({}, customMt or Checkpoint_mt)

    self.nodeId = nodeId

    self.isServer = isServer
    self.isClient = isClient

    self.isActive = false

    self.hasEntered = false
    self.hasEntered = false
    self.actionOnlyFulfillment = false

    return self
end

function Checkpoint:delete()
    if self.triggerNode ~= nil then
        removeTrigger(self.triggerNode)
    end
end

function Checkpoint:reset()
    self:setIsActive(false)
    self.hasEntered = false
    self.hasLeft = false
end

function Checkpoint:setIsActive(isActive)
    self.isActive = isActive

    if self.iconNode ~= nil then
        setVisibility(self.iconNode, isActive)
    end
end

function Checkpoint:hasPassedCheckpoint()
    return (self.hasEntered and self.hasLeft) or self.actionOnlyFulfillment
end

function Checkpoint:loadFromXML(xmlFile, baseKey)
    self.triggerNode = I3DUtil.indexToObject(self.nodeId, getXMLString(xmlFile, baseKey .. "#triggerNode"))
    if self.triggerNode ~= nil then
        addTrigger(self.triggerNode, "checkpointTriggerCallback", self)
    end

    self.iconNode = I3DUtil.indexToObject(self.nodeId, getXMLString(xmlFile, baseKey .. "#iconNode"))

    self:setIsActive(false)

    return true
end

function Checkpoint:checkpointTriggerCallback(triggerId, otherId, onEnter, onLeave, onStay, otherShapeId)
    if self.isActive then
        if onEnter then
            self.hasEntered = true
        end

        if self.hasEntered and onLeave then
            self.hasLeft = true
        end
    end
end
