----------------------------------------------------------------------------------------------------
-- LindnerSuperCupAreaPlaceable
----------------------------------------------------------------------------------------------------
-- Purpose: Placeable class for the super cup area.
--
-- Copyright (c) Wopster, 2020
----------------------------------------------------------------------------------------------------

LindnerSuperCupAreaPlaceable = {}
local LindnerSuperCupAreaPlaceable_mt = Class(LindnerSuperCupAreaPlaceable, Placeable)

InitObjectClass(LindnerSuperCupAreaPlaceable, "LindnerSuperCupAreaPlaceable")

function LindnerSuperCupAreaPlaceable:new(isServer, isClient, mt)
    local self = Placeable:new(isServer, isClient, mt or LindnerSuperCupAreaPlaceable_mt)

    registerObjectClassName(self, "LindnerSuperCupAreaPlaceable")

    return self
end

function LindnerSuperCupAreaPlaceable:delete()
    self.superCup:delete()

    unregisterObjectClassName(self)

    LindnerSuperCupAreaPlaceable:superClass().delete(self)
end

function LindnerSuperCupAreaPlaceable:load(xmlFilename, x, y, z, rx, ry, rz, initRandom)
    if not LindnerSuperCupAreaPlaceable:superClass().load(self, xmlFilename, x, y, z, rx, ry, rz, initRandom) then
        return false
    end

    local xmlFile = loadXMLFile("area", xmlFilename)

    self.superCup = SuperCup:new(g_currentMission, self.baseDirectory, self.customEnvironment, self:getOwnerFarmId(), self.nodeId)
    self.superCup:loadFromXML(xmlFile, "placeable.superCupArea")

    delete(xmlFile)

    return true
end

function LindnerSuperCupAreaPlaceable:saveToXMLFile(xmlFile, key, usedModNames)
    LindnerSuperCupAreaPlaceable:superClass().saveToXMLFile(self, xmlFile, key, usedModNames)
    self.superCup:saveToXMLFile(xmlFile, key .. ".superCupArea", usedModNames)
end

function LindnerSuperCupAreaPlaceable:finalizePlacement()
    LindnerSuperCupAreaPlaceable:superClass().finalizePlacement(self)

    self:raiseActive()
end

function LindnerSuperCupAreaPlaceable:update(dt)
    LindnerSuperCupAreaPlaceable:superClass().update(self, dt)

    self:raiseActive()
    self.superCup:update(dt)
    self.superCup:draw()
end
