----------------------------------------------------------------------------------------------------
-- FinishState
----------------------------------------------------------------------------------------------------
-- Purpose: Finish state for the state machine.
--
-- Copyright (c) Wopster, 2020
----------------------------------------------------------------------------------------------------

---@class FinishState
---@field public id number
FinishState = {}

local FinishState_mt = Class(FinishState, AbstractState)

---Creates a new finish state.
---@param id number
---@param stateMachine FSM
---@param custom_mt table
---@return FinishState
function FinishState:new(id, stateMachine, superCup, vehicleList, trafficLight, scores, hud, custom_mt)
    local self = AbstractState:new(id, stateMachine, custom_mt or FinishState_mt)

    self.superCup = superCup
    self.vehicleList = vehicleList
    self.trafficLight = trafficLight
    self.scores = scores
    self.hud = hud

    return self
end

---Called on delete.
function FinishState:delete()
    FinishState:superClass().delete(self)
end

---Called on enter.
function FinishState:onEnter(score)
    FinishState:superClass().onEnter(self)

    self.trafficLight:reset()

    for _, vehicle in ipairs(self.vehicleList) do
        if vehicle ~= nil and not vehicle.isDeleted then
            g_currentMission:removeVehicle(vehicle, false)
            vehicle:delete()
        end
    end

    self.vehicleList = {}

    if self.superCup.started then
        self.superCup:stopSuperCup()
    end

    if score ~= nil then
        table.insert(self.scores, score)
        --print_r(score)

        g_gui:showInfoDialog({
            dialogType = DialogElement.TYPE_INFO,
            text = g_i18n:getText("info_score"):format(score.playerNickname, score.time, score.penalties)
        })
    end

    self.hud:setIsActive(false)
end
